#
# spec file for package python-setproctitle
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-setproctitle
Version:        1.3.5
Release:        2.1
Summary:        Python module to allow customization of the process title
License:        BSD-3-Clause
URL:            https://github.com/dvarrazzo/py-setproctitle/
Source:         https://files.pythonhosted.org/packages/source/s/setproctitle/setproctitle-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Changing the title is mostly useful in multi-process systems, for example when
a master process is forked: changing the children's title allows to identify
the task each process is busy with. The technique is used by PostgreSQL  and
the OpenSSH Server for example.

%prep
%setup -q -n setproctitle-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# This is incompatible with qemu emulation
%if !0%{?qemu_user_space_build}
%pytest_arch
%endif

%files %{python_files}
%doc HISTORY.rst README.rst
%license COPYRIGHT
%{python_sitearch}/setproctitle
%{python_sitearch}/setproctitle-%{version}.dist-info

%changelog
* Mon Jun 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyroject macros.
* Wed Feb 26 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.3.5
  * Fix bouncing Dock icon on macOS (issue #143).
  * Fix building on C23 compilers (issue #145).
- Add fdupes to BuildRequires
- Run %%fdupes in %%install section
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.4:
  * Add support for Python 3.13 (issue #139).
  * Drop support for Python 3.7.
* Thu Dec 14 2023 Andreas Schwab <schwab@suse.de>
- Skip testsuite under qemu emulation
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.3:
  * Add support for Python 3.12
  * Fix package metadata to include Python 3.11, 3.12.
* Fri Sep 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Restore import-time initialization of macOS to avoid crash on thread+fork
  * Fixed segfault on macOS 12.5 in forked processes (issue #111).
    Note that, as a workaround, Activity Monitor will show the title of the
    parent.
  * Added fallback no-op implementation if building the extension fails.
  * Added support for displaying title as the process name in MacOS Activity
    Monitor (issue #10).
  * Fixed "Symbol not found: _Py_GetArgcArgv" error when using Xcode provided
    Python (issues #82, #103).
  * Fixed FreeBSD support, broken in 1.2 (issue #94).
  * Added package type annotations (issue #101).
  * Dropped support for Python 3.6.
* Wed May 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.3:
  * Added Python 3.10 packages (issue #102).
  * Added Wheel packages for macOS (issue #96).
* Thu Jan 28 2021 Dirk Müller <dmueller@suse.com>
- update to 1.2.2:
  - Fixed Windows build (issues #89, #90).
  - Added wheel packages for Windows (issues #47, #90).
  - Added wheel packages for aarch64 (issues #95).
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 1.2.1
  - Fixed segfault after ``os.environ.clear()`` (issue #88).
* Fri Dec  4 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 1.2
  * added ``getthreadtitle()`` and ``setthreadtitle()``.
  * Initialisation of the module moved to the first usage:
    importing the module doesn't cause side effects.
  * Manage much longer command lines (#52)
  * Improved build on BSD, dropped ancient versions (issue #67).
  * Fixed build for Python 3.8 (#66, #72)
  * Added support for Python 3.9
  * Dropped support for Python < 3.6
- Drop use-pkg-config.patch
- Drop extra requirements
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Revert to working test suite, re-adding use-pkg-config.patch,
  and replace nose with pytest
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove patch use-pkg-config.patch as we don't need to tweak
  this stuff at all
* Tue Mar 10 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update use-pkg-config.patch to use the embedded profile, to build
  against Python 3.8.
* Sun Sep 15 2019 John Vandenberg <jayvdb@gmail.com>
- Replace PyPI URL with GitHub URL
- Drop errant skip-failing-tests.patch caused by missing
  test dependency procps
- Add use-pkg-config.patch to build using pkg-config instead of
  python-config, as the latter is not shipped in python3-devel
- Add LANG in %%check to fix openSUSE/SLE 15
- Use %%license
* Sun Mar  3 2019 Matej Cepl <mcepl@suse.com>
- Enable tests and add skip-failing-tests.patch to skip failing tests
  (gh#dvarrazzo/py-setproctitle#60)
* Thu Jul  6 2017 tbechtold@suse.com
- update to 1.10.0:
  - Fixed building with certain ``prctl.h`` implementations (issue #44).
  - Use ``setuptools`` if available (issue #48).
  - Fixed build on VC (issues #20, #33).
  - Added ``MANIFEST.in`` to the source distribution to help with RPM building
    (issue #30).
- convert to singlespec
- fix Source url
* Tue Nov 19 2013 p.drouand@gmail.com
- Update to version 1.1.8
  + Added support for Python "diehard" 2.4.
  + Fixed build on Mac OS X 10.9 Maverick (issue #27).
* Sat Sep 14 2013 os-dev@jacraig.com
- Update to 1.1.7:
  * Added PyPy support, courtesy of Ozan Turksever (http://www.logsign.net).
* Mon Jan 14 2013 saschpe@suse.de
- Simplify macro usage
* Wed Sep 12 2012 os-dev@jacraig.com
- Update to 1.1.6:
  * The module can be compiled again on Windows (issue #21).
- Changes from 1.1.5:
  * No module bug, but a packaging issue: files ``README`` and ``HISTORY``
    added back into the distribution.
- Changes from 1.1.4:
  * The module works correctly in embedded Python.
  * ``setproctitle()`` accepts a keyword argument.
  * Debug output support always compiled in: the variable ``SPT_DEBUG`` can be
    used to emit debug log.
- Simplify %%build sections to one line
- HISTORY and README files are now .rst files, update %%files section
* Tue Jan 10 2012 idonmez@suse.com
- Update to v1.1.3
  * Don't clobber environ if the variable SPT_NOENV is set
  * Fixed segfault when the module is imported under vim (bnc#739242)
* Mon Apr  4 2011 jengelh@medozas.de
- Provide python3 spec file
* Tue Mar 29 2011 saschpe@suse.de
- Spec file cleanup:
  * changed license to BSD3c
  * packaded documentation files
  * fixed build non-SUSE distros
* Thu Nov 18 2010 hvogel@novell.com
- Update to version 1.1
  * add support python3
* Wed Jun 23 2010 hvogel@novell.com
- Initial package, Version 1.0.1
